package sun.security.x509;

import sun.security.util.DerOutputStream;
import java.io.IOException;
import sun.security.util.DerValue;
import sun.security.util.ObjectIdentifier;

public class OIDName implements GeneralNameInterface
{
    private ObjectIdentifier oid;
    
    public OIDName(DerValue derValue) throws IOException {
        this.oid = derValue.getOID();
    }
    
    public OIDName(ObjectIdentifier oid) {
        this.oid = oid;
    }
    
    public OIDName(String oid) throws IOException {
        try {
            this.oid = new ObjectIdentifier(oid);
        }
        catch (Exception obj) {
            throw new IOException("Unable to create OIDName: " + obj);
        }
    }
    
    @Override
    public int getType() {
        return 8;
    }
    
    @Override
    public void encode(DerOutputStream derOutputStream) throws IOException {
        derOutputStream.putOID(this.oid);
    }
    
    @Override
    public String toString() {
        return "OIDName: " + this.oid.toString();
    }
    
    public ObjectIdentifier getOID() {
        return this.oid;
    }
    
    @Override
    public boolean equals(Object o) {
        return this == o || (o instanceof OIDName && this.oid.equals(((OIDName)o).oid));
    }
    
    @Override
    public int hashCode() {
        return this.oid.hashCode();
    }
    
    @Override
    public int constrains(GeneralNameInterface generalNameInterface) throws UnsupportedOperationException {
        int n;
        if (generalNameInterface == null) {
            n = -1;
        }
        else if (generalNameInterface.getType() != 8) {
            n = -1;
        }
        else if (this.equals((GeneralNameInterface)generalNameInterface)) {
            n = 0;
        }
        else {
            throw new UnsupportedOperationException("Narrowing and widening are not supported for OIDNames");
        }
        return n;
    }
    
    @Override
    public int subtreeDepth() throws UnsupportedOperationException {
        throw new UnsupportedOperationException("subtreeDepth() not supported for OIDName.");
    }
}
